@@ -62,7 +62,9 @@ packages::
 
 """
 
+from distutils.version import LooseVersion
 import os
+import platform
 import sys
 import warnings
 
@@ -70,8 +72,8 @@ import warnings
 from ._version import __version__
 
 
-class PythonQtError(Exception):
-    """Error raise if no bindings could be selected"""
+class PythonQtError(RuntimeError):
+    """Error raise if no bindings could be selected."""
     pass
 
 
@@ -98,6 +100,9 @@ PYSIDE_API = ['pyside']
 # Names of the expected PySide2 api
 PYSIDE2_API = ['pyside2']
 
+# Detecting if a binding was specified by the user
+binding_specified = QT_API in os.environ
+
 # Setting a default value for QT_API
 os.environ.setdefault(QT_API, 'pyqt5')
 
@@ -111,13 +116,13 @@ PYQT4 = PYSIDE = PYSIDE2 = False
 
 
 if 'PyQt5' in sys.modules:
-    API = 'pyqt5'
+    API = initial_api if initial_api in PYQT5_API else 'pyqt5'
 elif 'PySide2' in sys.modules:
-    API = 'pyside2'
+    API = initial_api if initial_api in PYSIDE2_API else 'pyside2'
 elif 'PyQt4' in sys.modules:
-    API = 'pyqt4'
+    API = initial_api if initial_api in PYQT4_API else 'pyqt4'
 elif 'PySide' in sys.modules:
-    API = 'pyside'
+    API = initial_api if initial_api in PYSIDE_API else 'pyside'
 
 
 if API in PYQT5_API:
@@ -125,6 +130,23 @@ if API in PYQT5_API:
         from PyQt5.QtCore import PYQT_VERSION_STR as PYQT_VERSION  # analysis:ignore
         from PyQt5.QtCore import QT_VERSION_STR as QT_VERSION  # analysis:ignore
         PYSIDE_VERSION = None
+
+        if sys.platform == 'darwin':
+            macos_version = LooseVersion(platform.mac_ver()[0])
+            if macos_version < LooseVersion('10.10'):
+                if LooseVersion(QT_VERSION) >= LooseVersion('5.9'):
+                    raise PythonQtError("Qt 5.9 or higher only works in "
+                                        "macOS 10.10 or higher. Your "
+                                        "program will fail in this "
+                                        "system.")
+            elif macos_version < LooseVersion('10.11'):
+                if LooseVersion(QT_VERSION) >= LooseVersion('5.11'):
+                    raise PythonQtError("Qt 5.11 or higher only works in "
+                                        "macOS 10.11 or higher. Your "
+                                        "program will fail in this "
+                                        "system.")
+
+            del macos_version
     except ImportError:
         API = os.environ['QT_API'] = 'pyside2'
 
@@ -136,6 +158,17 @@ if API in PYSIDE2_API:
         PYQT_VERSION = None
         PYQT5 = False
         PYSIDE2 = True
+
+        if sys.platform == 'darwin':
+            macos_version = LooseVersion(platform.mac_ver()[0])
+            if macos_version < LooseVersion('10.11'):
+                if LooseVersion(QT_VERSION) >= LooseVersion('5.11'):
+                    raise PythonQtError("Qt 5.11 or higher only works in "
+                                        "macOS 10.11 or higher. Your "
+                                        "program will fail in this "
+                                        "system.")
+
+            del macos_version
     except ImportError:
         API = os.environ['QT_API'] = 'pyqt'
 
@@ -176,7 +209,7 @@ if API in PYSIDE_API:
 
 # If a correct API name is passed to QT_API and it could not be found,
 # switches to another and informs through the warning
-if API != initial_api:
+if API != initial_api and binding_specified:
     warnings.warn('Selected binding "{}" could not be found, '
                   'using "{}"'.format(initial_api, API), RuntimeWarning)
 
